- Deprecate module ``xoutil.logger``.

- Remove deprecated function ``xoutil.iterators.fake_dict_iteritems``.

- Add `xoutil.objects.temp_attributes`:func:.

- Add functions `~xoutil.fp.tools.fst`:func: and `~xoutil.fp.tools.snd`:func:.
